@@ -14,8 +14,8 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT = qw();
-our $VERSION = '0.02';
+our @EXPORT = qw(PreprocessorDepend);
+our $VERSION = '0.05';
 
 #------------------------------------------------------------------------------------------------
 
@@ -28,11 +28,15 @@ my $include_system_includes = shift ;
 my $add_child_callback      = shift ;
 my $display_cpp_output      = shift ;
 
-my $command = "$cpp -H -M $switches $file_to_depend 2>&1" ;
+
+my $redir_to_null = $^O eq "MSWin32" ? '> nul' : '1>/dev/null';
+
+my $command = "$cpp -H -M $switches $file_to_depend 2>&1 $redir_to_null" ;
+
 my $errors ;
 
 my @cpp_output = `$command` ;
-$errors = "command: $command : $!" unless @cpp_output ;
+$errors = "command: $command : $!" if $! ;
 
 for(@cpp_output)
 	{
@@ -54,6 +58,17 @@ Default search path from cpp Info pages:
 /usr/include/g++-v3
 =cut
 	@cpp_output = grep {! m~\.+\s+/usr/~ && /^\./} @cpp_output ;
+
+if ($^O eq 'MSWin32')
+{
+	my @includes = split(';', $ENV{INCLUDE});
+	for my $include (@includes)
+	{
+        $include =~ s|\\|/|g;
+		@cpp_output = grep { ! m~\.+\s+\Q$include~ && /^\./} @cpp_output ;
+	}
+}
+
 	}
 	
 my %node_levels ;
@@ -66,6 +81,8 @@ for(@cpp_output)
 	
 	chomp ;
 	my ($level, $name) = /^(\.+)\s+(.*)/ ;
+	$name =~ s|\\|/|g;
+
 	$level = length $level ;
 	
 	my $node ;
@@ -92,6 +109,8 @@ for(@cpp_output)
 return((! defined $errors), \%node_levels, \%nodes, $parent_at_level{0}, $errors) ;
 }
 
+*PreprocessorDepend = \&Depend;
+
 #-------------------------------------------------------------------------------
 
 1 ;
