@@ -83,7 +83,7 @@ my $pbsfile = "ExcludeFromDigestGeneration('header files' => qr/\.h\$/) ;\n" ;
 my $sub = sub
 	{
 	my ($parent, $child) = @_ ;
-	$pbsfile .= "AddRule '$parent<$child', ['$parent' => '$child'], BuildOk() ;\n" ;
+	$pbsfile .= "AddRule '$parent => $child', ['$parent' => '$child'], BuildOk() ;\n" ;
 	} ;
 
 my ($depend_ok, $levels, $nodes, $tree, $errors) = Devel::Depend::Cpp::Depend(undef, $file_to_depend, $switches, $include_system_includes, $sub, $display_cpp_output) ;
